@@ -1,12 +1,12 @@
 package FusionInventory::Agent::Task::Inventory::IpDiscover;
 
 use strict;
+use warnings;
 
 sub isInventoryEnabled {
     my $params = shift;
 
     my $prologresp = $params->{prologresp};
-    my $mem = $params->{mem};
 
     return unless ($prologresp && $prologresp->getOptionsInfoByName("IPDISCOVER"));
 
